summaryrefslogtreecommitdiff
path: root/gst/multipart/multipartmux.h
diff options
context:
space:
mode:
authorMark Nauwelaerts <mark.nauwelaerts@collabora.co.uk>2012-04-17 15:14:27 +0200
committerMark Nauwelaerts <mark.nauwelaerts@collabora.co.uk>2012-04-17 15:14:27 +0200
commit67e168aef4ca240cb27cf8e21f3b6822d98c42c8 (patch)
tree1409afdffdfefa67e686c0f609a726bb81dd27ff /gst/multipart/multipartmux.h
parent04b4d30f2cf7f8196703e14647cbb88b7ec1ad37 (diff)
collectpads2: rename to collectpads
Diffstat (limited to 'gst/multipart/multipartmux.h')
-rw-r--r--gst/multipart/multipartmux.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/gst/multipart/multipartmux.h b/gst/multipart/multipartmux.h
index 4583b5098..d2711ac0e 100644
--- a/gst/multipart/multipartmux.h
+++ b/gst/multipart/multipartmux.h
@@ -23,7 +23,7 @@
#define __GST_MULTIPART_MUX__
#include <gst/gst.h>
-#include <gst/base/gstcollectpads2.h>
+#include <gst/base/gstcollectpads.h>
#include <string.h>
@@ -42,7 +42,7 @@ typedef struct _GstMultipartMuxClass GstMultipartMuxClass;
/* all information needed for one multipart stream */
typedef struct
{
- GstCollectData2 collect; /* we extend the CollectData2 */
+ GstCollectData collect; /* we extend the CollectData */
GstBuffer *buffer; /* the queued buffer for this pad */
GstClockTime timestamp; /* its timestamp, converted to running_time so that we can
@@ -64,7 +64,7 @@ struct _GstMultipartMux
GstPad *srcpad;
/* sinkpads */
- GstCollectPads2 *collect;
+ GstCollectPads *collect;
gint numpads;